@@ -2,9 +2,9 @@
 
 # Build zipfiles for ATK on Win32
 
-ZIP=/tmp/atk-1.1.0-`date +%Y%m%d`.zip
-DEVZIP=/tmp/atk-dev-1.1.0-`date +%Y%m%d`.zip
-cd /usr
+ZIP=/tmp/atk-1.1.1-`date +%Y%m%d`.zip
+DEVZIP=/tmp/atk-dev-1.1.1-`date +%Y%m%d`.zip
+cd /usr/gnome
 
 rm $ZIP
 zip -r $ZIP -@ <<EOF
