@@ -3,22 +3,6 @@
 
 #include <atk.h>
 
-/* enumerations from "atkhyperlink.h" */
-GType
-atk_hyperlink_state_flags_get_type (void)
-{
-  static GType etype = 0;
-  if (etype == 0) {
-    static const GFlagsValue values[] = {
-      { ATK_HYPERLINK_IS_INLINE, "ATK_HYPERLINK_IS_INLINE", "inline" },
-      { 0, NULL, NULL }
-    };
-    etype = g_flags_register_static ("AtkHyperlinkStateFlags", values);
-  }
-  return etype;
-}
-
-
 /* enumerations from "atkobject.h" */
 GType
 atk_role_get_type (void)
@@ -99,18 +83,6 @@ atk_role_get_type (void)
       { ATK_ROLE_FOOTER, "ATK_ROLE_FOOTER", "footer" },
       { ATK_ROLE_PARAGRAPH, "ATK_ROLE_PARAGRAPH", "paragraph" },
       { ATK_ROLE_RULER, "ATK_ROLE_RULER", "ruler" },
-      { ATK_ROLE_APPLICATION, "ATK_ROLE_APPLICATION", "application" },
-      { ATK_ROLE_AUTOCOMPLETE, "ATK_ROLE_AUTOCOMPLETE", "autocomplete" },
-      { ATK_ROLE_EDITBAR, "ATK_ROLE_EDITBAR", "editbar" },
-      { ATK_ROLE_EMBEDDED, "ATK_ROLE_EMBEDDED", "embedded" },
-      { ATK_ROLE_ENTRY, "ATK_ROLE_ENTRY", "entry" },
-      { ATK_ROLE_CHART, "ATK_ROLE_CHART", "chart" },
-      { ATK_ROLE_CAPTION, "ATK_ROLE_CAPTION", "caption" },
-      { ATK_ROLE_DOCUMENT_FRAME, "ATK_ROLE_DOCUMENT_FRAME", "document-frame" },
-      { ATK_ROLE_HEADING, "ATK_ROLE_HEADING", "heading" },
-      { ATK_ROLE_PAGE, "ATK_ROLE_PAGE", "page" },
-      { ATK_ROLE_SECTION, "ATK_ROLE_SECTION", "section" },
-      { ATK_ROLE_REDUNDANT_OBJECT, "ATK_ROLE_REDUNDANT_OBJECT", "redundant-object" },
       { ATK_ROLE_LAST_DEFINED, "ATK_ROLE_LAST_DEFINED", "last-defined" },
       { 0, NULL, NULL }
     };
@@ -158,10 +130,6 @@ atk_relation_type_get_type (void)
       { ATK_RELATION_FLOWS_TO, "ATK_RELATION_FLOWS_TO", "flows-to" },
       { ATK_RELATION_FLOWS_FROM, "ATK_RELATION_FLOWS_FROM", "flows-from" },
       { ATK_RELATION_SUBWINDOW_OF, "ATK_RELATION_SUBWINDOW_OF", "subwindow-of" },
-      { ATK_RELATION_EMBEDS, "ATK_RELATION_EMBEDS", "embeds" },
-      { ATK_RELATION_EMBEDDED_BY, "ATK_RELATION_EMBEDDED_BY", "embedded-by" },
-      { ATK_RELATION_POPUP_FOR, "ATK_RELATION_POPUP_FOR", "popup-for" },
-      { ATK_RELATION_PARENT_WINDOW_OF, "ATK_RELATION_PARENT_WINDOW_OF", "parent-window-of" },
       { ATK_RELATION_LAST_DEFINED, "ATK_RELATION_LAST_DEFINED", "last-defined" },
       { 0, NULL, NULL }
     };
@@ -208,12 +176,6 @@ atk_state_type_get_type (void)
       { ATK_STATE_VERTICAL, "ATK_STATE_VERTICAL", "vertical" },
       { ATK_STATE_VISIBLE, "ATK_STATE_VISIBLE", "visible" },
       { ATK_STATE_MANAGES_DESCENDANTS, "ATK_STATE_MANAGES_DESCENDANTS", "manages-descendants" },
-      { ATK_STATE_INDETERMINATE, "ATK_STATE_INDETERMINATE", "indeterminate" },
-      { ATK_STATE_TRUNCATED, "ATK_STATE_TRUNCATED", "truncated" },
-      { ATK_STATE_REQUIRED, "ATK_STATE_REQUIRED", "required" },
-      { ATK_STATE_INVALID_ENTRY, "ATK_STATE_INVALID_ENTRY", "invalid-entry" },
-      { ATK_STATE_SUPPORTS_AUTOCOMPLETION, "ATK_STATE_SUPPORTS_AUTOCOMPLETION", "supports-autocompletion" },
-      { ATK_STATE_SELECTABLE_TEXT, "ATK_STATE_SELECTABLE_TEXT", "selectable-text" },
       { ATK_STATE_LAST_DEFINED, "ATK_STATE_LAST_DEFINED", "last-defined" },
       { 0, NULL, NULL }
     };
@@ -286,23 +248,6 @@ atk_text_boundary_get_type (void)
   return etype;
 }
 
-GType
-atk_text_clip_type_get_type (void)
-{
-  static GType etype = 0;
-  if (etype == 0) {
-    static const GEnumValue values[] = {
-      { ATK_TEXT_CLIP_NONE, "ATK_TEXT_CLIP_NONE", "none" },
-      { ATK_TEXT_CLIP_MIN, "ATK_TEXT_CLIP_MIN", "min" },
-      { ATK_TEXT_CLIP_MAX, "ATK_TEXT_CLIP_MAX", "max" },
-      { ATK_TEXT_CLIP_BOTH, "ATK_TEXT_CLIP_BOTH", "both" },
-      { 0, NULL, NULL }
-    };
-    etype = g_enum_register_static ("AtkTextClipType", values);
-  }
-  return etype;
-}
-
 
 /* enumerations from "atkutil.h" */
 GType
